﻿using System;
using System.IO;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Net.Sockets;
using System.Net;

namespace location
{
    public class ProtocolChoice
    {
        ArgBreaker protocolName;
        StreamWriter sw;

        /// <summary>
        /// Constructor for the ProtocolChoice class. It breaks the arguments down and returns the protocol
        /// </summary>
        /// <param name="args">Arguments the client gets</param>
        /// <param name="client">TCPClient</param>
        public ProtocolChoice(string[] args,TcpClient client)
        {
            protocolName = new ArgBreaker(args);
            string ipAddress = protocolName.ipAddressStringGET();
            int portNo = protocolName.portNoGET();
            
            client.Connect(ipAddress, portNo);
            
            sw = new StreamWriter(client.GetStream());
            chooseProtocol(args, client, ipAddress, portNo);
        }
        private void chooseProtocol(string[] args, TcpClient client, string ipAddress, int portNo)
        {
            string protocol = protocolName.protocolGET();
            string name = protocolName.nameGET();
            string location = protocolName.locationGET();
            switch (protocol)
            {
                case "-h9":
                    httpNine(args, client, name, location);                                     //Not sure, but you might be able to pass long the name and location.
                    break;                                                                      //Try it. nameGET / locationGET.
                case "-h1":
                    httpOneOne(args, client, name, location, ipAddress);
                    break;
                case "-h0":
                    httpTen(args, client, name, location);
                    break;
                case "Whois":
                    whoIS(args, client, name, location);
                    break;
            }
        }

        /// <summary>
        /// Does the work for protocol HTTP1.1
        /// </summary>
        /// <param name="args">Arguments the client gets</param>
        /// <param name="client">TCPClient</param>
        private void httpOneOne(string[] args, TcpClient client, string name, string location, string ipAddress)
        {
            //Spilt apart arguments for HTTP 1.1
            //Remember to flush each time

            if (location == null)
            {
                //Do GET
                sw.WriteLine("GET" + " " + "/" + name + " " + "HTTP/1.1" + "\n" + "Host:" + " " + ipAddress + "\n" + "\n");
                sw.Flush();
            }
            else
            {
                //Do POST
                sw.WriteLine("POST" + " " + "/" + name + " " + "HTTP/1.1" + "\n" + "Host:" + " " + ipAddress + "\n" + "Content-Length" + " " + location.Length + "\n\n" + location + "\n");
                sw.Flush();
            }

            HTTP11Read httpOneOne = new HTTP11Read(client, args, name, location);
        }

        /// <summary>
        /// Does the work for protocol HTTP0.9
        /// </summary>
        /// <param name="args">Arguments the client gets</param>
        /// <param name="client">TCPClient</param>
        private void httpNine(string[] args, TcpClient client, string name, string location)
        {
            //Spilt apart arguments for HTTP 0.9
            //Remember to flush each time

            if (location == null)
            {
                //Do GET
                sw.WriteLine("GET" + " " + "/" + name + "\n");
                sw.Flush();
            }
            else
            {
                //Do POST
                sw.WriteLine("PUT" + " " + "/" + name + "\n" + "\n" + location + "\n");
                sw.Flush();
            }

            HTTP09Read httpNine = new HTTP09Read(client, args, name, location);

        }

        /// <summary>
        /// Does the work for protocol HTTP1.0
        /// </summary>
        /// <param name="args">Arguments the client gets</param>
        /// <param name="client">TCPClient</param>
        private void httpTen(string[] args, TcpClient client, string name, string location)
        {
            //Spilt apart arguments for HTTP 1.0
            //Remember to flush each time

            if (location == null)
            {
                //Do GET
                sw.WriteLine("GET" + " " + "/" + name + " " + "HTTP/1.0" + "\n" + "\n");
                sw.Flush();
            }
            else
            {
                //Do POST
                sw.WriteLine("POST" + " " + "/" + name + " " + "HTTP/1.0" + "\n" + "Content-Length" + " " + location.Length + "\n\n" + location + "\n");
                sw.Flush();
            }
            
            HTTP10Read httpTen = new HTTP10Read(client, args, name, location);
        }

        /// <summary>
        /// Does the work for protocol Whois
        /// </summary>
        /// <param name="args">Arguments the client gets</param>
        /// <param name="client">TCPClient</param>
        private void whoIS(string[] args, TcpClient client, string name, string location)
        {

            if (location == null)
            {
                sw.WriteLine(name);
                sw.Flush();
            }
            else
            {
                sw.WriteLine(name + " " + location);
                sw.Flush();
            }
            WhoIsRead readWhois = new WhoIsRead(client, args, name, location); //Calls the WhoisRead class
        }
    }
}
